#[non_exhaustive]pub enum Status {
Show 16 variants
Success,
NotInitialized,
AllocFailed,
InvalidValue,
ArchitectureMismatch,
MappingError,
ExecutionFailed,
InternalError,
NotSupported,
LicenseError,
CublasError,
CudaError,
InsufficientWorkspace,
InsufficientDriver,
IoError,
Unknown(u32),
}Expand description
cuTENSOR status returned by library calls.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Success
The operation completed successfully.
NotInitialized
The opaque data structure was not initialized.
AllocFailed
Resource allocation failed inside the cuTENSOR library.
InvalidValue
An unsupported value or parameter was passed to the operation.
ArchitectureMismatch
The device is not ready, or the target architecture is not supported.
MappingError
An access to GPU memory space failed, which is usually caused by a failure to bind a texture.
ExecutionFailed
The GPU program failed to execute. A kernel launch failure on the GPU is a common cause.
InternalError
An internal cuTENSOR error occurred.
NotSupported
The requested operation is not supported.
LicenseError
The requested operation requires a license, and an error was detected when checking the current licensing.
CublasError
A call to cuBLAS did not succeed.
CudaError
An unknown CUDA error occurred.
InsufficientWorkspace
The provided workspace was insufficient.
InsufficientDriver
Indicates that the driver version is insufficient.
IoError
Indicates an error related to file I/O.
Unknown(u32)
A status code not known to this version of Singe.