ContractionFind

Struct ContractionFind 

pub struct ContractionFind { /* private fields */ }

Implementations

Source

impl ContractionFind

pub fn create(context: &Context, algorithm: Algorithm) -> Result<Self>

pub fn create_default(context: &Context) -> Result<Self>

pub unsafe fn from_raw( handle: cutensorMgContractionFind_t, context: &Context, algorithm: Algorithm, ) -> Result<Self>

Wraps an existing cuTENSORMg contraction find handle.

Safety

handle must be a valid cuTENSORMg contraction find handle associated with context and algorithm. The returned value takes ownership of handle and destroys it on drop.

pub fn algorithm(&self) -> Algorithm

pub fn set_attribute<T>( &mut self, attr: ContractionFindAttribute, value: &T, ) -> Result<()>

pub const fn as_raw(&self) -> cutensorMgContractionFind_t

pub fn into_raw(self) -> cutensorMgContractionFind_t

Consumes this find handle and returns the owned raw cuTENSORMg handle.

The caller becomes responsible for destroying the handle.