pub struct OperationDescriptor<'comm> { /* private fields */ }Implementations
Sourceimpl<'comm> OperationDescriptor<'comm>
impl<'comm> OperationDescriptor<'comm>
pub fn create_contraction( context: &Context<'comm>, a: &TensorDescriptor<'comm>, modes_a: &[Mode], op_a: Operator, b: &TensorDescriptor<'comm>, modes_b: &[Mode], op_b: Operator, c: &TensorDescriptor<'comm>, modes_c: &[Mode], op_c: Operator, d: &TensorDescriptor<'comm>, modes_d: &[Mode], compute: ComputeDescriptor, ) -> Result<Self>
Sourcepub unsafe fn from_raw(
handle: cutensorMpOperationDescriptor_t,
context: &Context<'comm>,
) -> Result<Self>
pub unsafe fn from_raw( handle: cutensorMpOperationDescriptor_t, context: &Context<'comm>, ) -> Result<Self>
Wraps an existing cuTENSORMp operation descriptor.
Safety
handle must be a valid cuTENSORMp operation descriptor associated with
context. The returned value takes ownership of handle and destroys
it on drop.
pub const fn as_raw(&self) -> cutensorMpOperationDescriptor_t
Sourcepub fn into_raw(self) -> cutensorMpOperationDescriptor_t
pub fn into_raw(self) -> cutensorMpOperationDescriptor_t
Consumes this descriptor and returns the owned raw cuTENSORMp operation descriptor.
The caller becomes responsible for destroying the descriptor.