pub struct TensorDescriptor { /* private fields */ }Implementations
Sourceimpl TensorDescriptor
impl TensorDescriptor
pub fn create_for<T: DataTypeLike>( ctx: &Context, shape: &[u64], alignment_requirement: u32, ) -> Result<Self>
pub fn create( ctx: &Context, shape: &[u64], data_type: DataType, alignment_requirement: u32, ) -> Result<Self>
Sourcepub fn create_with_strides(
ctx: &Context,
shape: &[u64],
strides: Option<&[u64]>,
data_type: DataType,
alignment_requirement: u32,
) -> Result<Self>
pub fn create_with_strides( ctx: &Context, shape: &[u64], strides: Option<&[u64]>, data_type: DataType, alignment_requirement: u32, ) -> Result<Self>
Creates a tensor descriptor.
This allocates a small amount of host memory.
The descriptor frees the associated cuTENSOR resources when dropped.
This non-blocking call is thread-safe but not reentrant.
Errors
Returns an error if the context cannot be bound, shape and strides
have different ranks, an extent or stride cannot be represented for
cuTENSOR, the data type or descriptor layout is unsupported, or cuTENSOR
returns a null descriptor handle.
pub fn create_with_strides_for<T: DataTypeLike>( ctx: &Context, shape: &[u64], strides: Option<&[u64]>, alignment_requirement: u32, ) -> Result<Self>
pub fn shape(&self) -> &[u64]
pub fn strides(&self) -> Option<&[u64]>
pub fn rank(&self) -> u32
pub fn data_type(&self) -> DataType
pub fn alignment_requirement(&self) -> u32
pub const fn as_raw(&self) -> cutensorTensorDescriptor_t