AutotuneMode

Enum AutotuneMode 

#[non_exhaustive]
#[repr(u32)]
pub enum AutotuneMode { None = 0, Incremental = 1, }
Controls cuTENSOR autotuning behavior.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


None = 0

Indicates no autotuning (default); the cache reduces plan-creation overhead. On a cache hit, the cached plan is reused; otherwise the plan cache is ignored.



Incremental = 1

Indicates incremental autotuning. Each corresponding sys::cutensorCreatePlan invocation creates a plan based on a different algorithm or kernel. PlanPreferenceAttribute::IncrementalCount defines the maximum number of kernels tested. May choose different algorithms across plan creations, so it does not guarantee bitwise-identical results.