PlanPreferenceAttribute

Enum PlanPreferenceAttribute 

#[non_exhaustive]
#[repr(u32)]
pub enum PlanPreferenceAttribute { AutotuneMode = 0, CacheMode = 1, IncrementalCount = 2, Algorithm = 3, KernelRank = 4, JitMode = 5, GpuArch = 6, }
Attributes of a PlanPreference that can be read or modified.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


AutotuneMode = 0

AutotuneMode: determines whether recurrent executions of the plan autotune.



CacheMode = 1

CacheMode: determines whether the algorithm or kernel for this plan is cached and controls what is considered a cache hit.



IncrementalCount = 2



Algorithm = 3

Algorithm: fixes the algorithm.



KernelRank = 4

i32: fixes a kernel subvariant of an algorithm; for example, kernel_rank == 1 with Algorithm::Tgett selects the second-best GETT kernel variant according to cuTENSOR’s performance model, while kernel_rank == 2 selects the third-best.



JitMode = 5

JitMode: determines whether just-in-time compilation is enabled (default: JitMode::None).



GpuArch = 6

i32: plan for a specific GPU architecture instead of the architecture associated with the context. The value encodes the SM version as 10 * SM.major + SM.minor. Currently only SM versions 80, 90 and 100 are supported.