#[repr(u32)]pub enum Status {
Show 15 variants
Success = 0,
NotInitialized = 1,
AllocFailed = 3,
InvalidValue = 7,
ArchMismatch = 8,
MappingError = 11,
ExecutionFailed = 13,
InternalError = 14,
NotSupported = 15,
LicenseError = 16,
CublasError = 17,
CudaError = 18,
InsufficientWorkspace = 19,
InsufficientDriver = 20,
IoError = 21,
}Expand description
cuTENSOR status returned by library calls.
Variants
Success = 0
The operation completed successfully.
NotInitialized = 1
The opaque data structure was not initialized.
AllocFailed = 3
Resource allocation failed inside the cuTENSOR library.
InvalidValue = 7
An unsupported value or parameter was passed to the operation.
ArchMismatch = 8
The device is not ready, or the target architecture is not supported.
MappingError = 11
An access to GPU memory space failed, which is usually caused by a failure to bind a texture.
ExecutionFailed = 13
The GPU program failed to execute. A kernel launch failure on the GPU is a common cause.
InternalError = 14
An internal cuTENSOR error occurred.
NotSupported = 15
The requested operation is not supported.
LicenseError = 16
The requested operation requires a license, and an error was detected when checking the current licensing.
CublasError = 17
A call to cuBLAS did not succeed.
CudaError = 18
An unknown CUDA error occurred.
InsufficientWorkspace = 19
The provided workspace was insufficient.
InsufficientDriver = 20
Indicates that the driver version is insufficient.
IoError = 21
Indicates an error related to file I/O.