pub struct Context { /* private fields */ }Implementations
Sourceimpl Context
impl Context
Sourcepub fn create(devices: &[i32]) -> Result<Self>
pub fn create(devices: &[i32]) -> Result<Self>
Creates a cuTENSORMg handle for the devices that may participate in later operations.
Errors
Returns an error if the device count cannot be represented by cuTENSORMg, if cuTENSORMg cannot create a handle, or if it returns a null handle.
pub fn devices(&self) -> &[i32]
pub fn device_count(&self) -> usize
pub fn as_raw(&self) -> cutensorMgHandle_t