pub struct CopyPlan { /* private fields */ }Implementations
Sourceimpl CopyPlan
impl CopyPlan
pub fn create( context: &Context, desc: &CopyDescriptor, workspace: Workspace, ) -> Result<Self>
pub fn workspace(&self) -> &Workspace
Sourcepub unsafe fn copy_raw(
&self,
dst: &mut [*mut ()],
src: &[*const ()],
device_workspace: &mut [*mut ()],
host_workspace: *mut (),
streams: &[StreamBinding],
) -> Result<()>
pub unsafe fn copy_raw( &self, dst: &mut [*mut ()], src: &[*const ()], device_workspace: &mut [*mut ()], host_workspace: *mut (), streams: &[StreamBinding], ) -> Result<()>
Executes this copy plan with raw distributed tensor pointers.
Safety
The pointer arrays must match the tensor descriptors used to create the plan. Device workspace pointers and streams must be ordered like the MG context devices.
pub const fn as_raw(&self) -> cutensorMgCopyPlan_t