pub struct TensorDescriptor<'comm> { /* private fields */ }Implementations
Sourceimpl<'comm> TensorDescriptor<'comm>
impl<'comm> TensorDescriptor<'comm>
pub fn create_for<T: DataTypeLike>( context: &Context<'comm>, shape: &[u64], ranks_per_mode: &[u64], rank_count: u32, ) -> Result<Self>
pub fn create( context: &Context<'comm>, config: TensorDescriptorConfig<'_>, ) -> Result<Self>
Sourcepub unsafe fn from_raw(
handle: cutensorMpTensorDescriptor_t,
context: &Context<'comm>,
config: TensorDescriptorConfig<'_>,
) -> Result<Self>
pub unsafe fn from_raw( handle: cutensorMpTensorDescriptor_t, context: &Context<'comm>, config: TensorDescriptorConfig<'_>, ) -> Result<Self>
Wraps an existing cuTENSORMp tensor descriptor.
Safety
handle must be a valid cuTENSORMp tensor descriptor associated with
context. The metadata in config must describe the raw descriptor.
The returned value takes ownership of handle and destroys it on drop.
pub fn rank(&self) -> u32
pub fn shape(&self) -> &[u64]
pub fn element_stride(&self) -> Option<&[u64]>
pub fn block_size(&self) -> Option<&[u64]>
pub fn block_stride(&self) -> Option<&[u64]>
pub fn ranks_per_mode(&self) -> &[u64]
pub fn ranks(&self) -> Option<&[i32]>
pub fn rank_count(&self) -> u32
pub fn data_type(&self) -> DataType
pub const fn as_raw(&self) -> cutensorMpTensorDescriptor_t
Sourcepub fn into_raw(self) -> cutensorMpTensorDescriptor_t
pub fn into_raw(self) -> cutensorMpTensorDescriptor_t
Consumes this descriptor and returns the owned raw cuTENSORMp tensor descriptor.
The caller becomes responsible for destroying the descriptor.